<div class="panel panel-default">
    <div class="panel-heading">Agent Status
    </div>
    <div class="panel-body">

        <dl class="dl-horizontal">

            <dt>Total :</dt>
            <dd>{{item.total}}</dd>

            <dt>Queued :</dt>
            <dd>{{item.queued}}</dd>

            <dt>Processing :</dt>
            <dd>{{item.processing}}</dd>

            <dt>Last Update (UTC) :</dt>
            <dd>{{item.update}}</dd>
        </dl>
    </div>
</div>